@@ -14,20 +14,19 @@ from ormigrate.toolbox import HelperFunctions as hf
 from wikifile.wikiFileManager import WikiFileManager
 from wikifile.wikiFile import WikiFile
 from wikifile.wikiRender import WikiRender
-import inspect
 import os
 import time
 import ntpath
 from pathlib import Path
 from openresearch.openresearch import OpenResearch
 
-from ormigrate.issue41 import AcronymLengthFixer
-from ormigrate.issue119_Ordinals import OrdinalFixer
-from ormigrate.issue71 import DateFixer
+from ormigrate.issue41_acronym import AcronymLengthFixer
+from ormigrate.issue119_ordinal import OrdinalFixer
+from ormigrate.issue71_date import DateFixer
 from ormigrate.eventSeriesFixer import EventSeriesProvenanceFixer, EventSeriesTitleFixer
-from ormigrate.issue152 import AcceptanceRateFixer
+from ormigrate.issue152_acceptancerate import AcceptanceRateFixer
 from ormigrate.issue170_curation import CurationQualityChecker
-from ormigrate.issue195 import BiblographicFieldFixer
+from ormigrate.issue195_biblographic import BiblographicFieldFixer
 
 
 class OREntity(JSONAble):
@@ -66,6 +65,7 @@ class OREntityList(JSONAbleList):
         self.debug=False
         self.wikiClient=None
         self.wikiPush=None
+        self.wikiFileManger=None
         self.askExtra=""
 
     def getList(self):
@@ -237,7 +237,7 @@ class OREntityList(JSONAbleList):
     def fromWikiSonBackupFiles(self,wikiSonName,backupdir=str(Path.home() / 'wikibackup'/ 'or' ),wikiId= 'or',listOfItems=[]):
         """
         Create me from the backup wiki files of OR Entity
-
+        ToDo: Migrate this functionality to WikiFileManager class in wikirender
         """
         filepaths = list(hf.absoluteFilePaths(backupdir))
         wikiRender = WikiRender()
@@ -252,8 +252,8 @@ class OREntityList(JSONAbleList):
             else:
                 wikiFile = WikiFile(filename,filepath,wikiRender)
                 wikiFileList.append(wikiFile)
-        wikiFileManger= WikiFileManager(wikiId)
-        LOD=wikiFileManger.convertWikiFilesToLOD(wikiFileList,wikiSonName)
+        self.wikiFileManger= WikiFileManager(wikiId,login=False)
+        LOD=self.wikiFileManger.convertWikiFilesToLOD(wikiFileList,wikiSonName)
         self.fromLoD(LOD)
 
     def getLoD(self):
@@ -374,25 +374,35 @@ class EventSeries(OREntity):
         return samplesWikiSon
     
     @classmethod       
-    def rateMigration(cls,eventSeries,eventSeriesRecord):
+    def rateMigration(cls,eventSeries,eventSeriesRecord,pageFixerList=None,limit=None):
         '''
         get the ratings from the different fixers
         '''
-        pageFixerList= [
-            {
-                "column": "provenancePainRating",
-                "fixer": EventSeriesProvenanceFixer
-            },
-            {
-                "column": "curationPainRating",
-                "fixer": CurationQualityChecker
-            },
-            {
-                "column": "titlePainRating",
-                "fixer": EventSeriesTitleFixer
-            }
-        ]
-        return PageFixer.rateWithFixers(pageFixerList, eventSeries,eventSeriesRecord)
+        if pageFixerList is None:
+            pageFixerList= [
+                {
+                    "column": "provenancePainRating",
+                    "fixer": EventSeriesProvenanceFixer
+                },
+                {
+                    "column": "curationPainRating",
+                    "fixer": CurationQualityChecker
+                },
+                {
+                    "column": "titlePainRating",
+                    "fixer": EventSeriesTitleFixer
+                }
+            ]
+        if limit is None:
+            return PageFixer.rateWithFixers(pageFixerList, eventSeries, eventSeriesRecord)
+        else:
+            for record in pageFixerList:
+                fixer = record["fixer"]
+                column = record["column"]
+                error = PageFixer.rateWithFixers(pageFixerList, eventSeries, eventSeriesRecord)
+                if eventSeriesRecord[column].pain >= limit:
+                    return error
+            return None
         
     
     def __str__(self):
@@ -443,7 +453,7 @@ class Event(OREntity):
             "pageTitle": "ICSME 2020",
             "acronym":"ICSME 2020",
             "ordinal": 36,
-            "evenType": "Conference",
+            "eventType": "Conference",
             "subject": "Software engineering",
             "startDate":  datetime.fromisoformat("2020-09-27"),
             "endDate":  datetime.fromisoformat("2020-09-27")
@@ -479,7 +489,13 @@ class Event(OREntity):
             "pageTitle": "5GU 2017",
             "startDate": datetime.fromisoformat("2017-06-08T00:00:00"),
             "title": "2nd EAI International Conference on 5G for Ubiquitous Connectivity"
+        },
+        {
+            'acronym': "IDC 2009",
+            'title': "The 8th International Conference on Interaction Design and Children",
+            'pageTitle': 'IDC 2009'
         }
+
         ]
         return samplesLOD
     
@@ -532,37 +548,47 @@ This CfP was obtained from [http://www.wikicfp.com/cfp/servlet/event.showcfp?eve
 
             
     @classmethod       
-    def rateMigration(cls,event,eventRecord):
+    def rateMigration(cls,event,eventRecord,pageFixerList=None,limit= None):
         '''
         get the ratings from the different fixers
         '''
-        pageFixerList= [
-            {
-                "column": "curationPainRating",
-                "fixer": CurationQualityChecker
-            },
-            {
-                "column": "acronymPainRating",
-                "fixer": AcronymLengthFixer
-            },
-            {
-                "column": "ordinalPainRating",
-                "fixer": OrdinalFixer
-            },
-            {
-                "column": "datePainRating",
-                "fixer": DateFixer
-            },
-            {
-                "column": "AcceptanceRatePainRating",
-                "fixer": AcceptanceRateFixer
-            },
-            {
-                "column": "BiblographicFieldFixer",
-                "fixer": BiblographicFieldFixer
-            }
-        ]
-        return PageFixer.rateWithFixers(pageFixerList, event,eventRecord)
+        if pageFixerList is None:
+            pageFixerList= [
+                {
+                    "column": "curationPainRating",
+                    "fixer": CurationQualityChecker
+                },
+                {
+                    "column": "acronymPainRating",
+                    "fixer": AcronymLengthFixer
+                },
+                {
+                    "column": "ordinalPainRating",
+                    "fixer": OrdinalFixer
+                },
+                {
+                    "column": "datePainRating",
+                    "fixer": DateFixer
+                },
+                {
+                    "column": "AcceptanceRatePainRating",
+                    "fixer": AcceptanceRateFixer
+                },
+                {
+                    "column": "BiblographicFieldFixer",
+                    "fixer": BiblographicFieldFixer
+                }
+            ]
+        if limit is None:
+            return PageFixer.rateWithFixers(pageFixerList, event,eventRecord)
+        else:
+            for record in pageFixerList:
+                column = record["column"]
+                error = PageFixer.rateWithFixers(pageFixerList, event, eventRecord)
+                if eventRecord[column].pain >= limit:
+                    return error
+            return None
+
     
     def __str__(self):
         text=self.pageTitle
