@@ -40,6 +40,12 @@ class HelperFunctions:
             for f in filenames:
                 yield os.path.abspath(os.path.join(dirpath, f))
 
+    @classmethod
+    def ensureDirectoryExists(cls,file_path):
+        directory = os.path.dirname(file_path)
+        if not os.path.exists(directory):
+            os.makedirs(directory)
+
     @classmethod
     def getSMW_WikiUser(cls,wikiId="or",save=False):
         '''
@@ -100,7 +106,7 @@ class HelperFunctions:
 
     @classmethod
     def wikiSontoLOD(self, wiki_sample, entity="Event"):
-        regex= '{{ *%s(?:.|\r|\n)*\}}' % entity
+        regex= r'{{ *%s(?:.|\r|\n)*\}}' % entity
         re_groups=re.search(regex,wiki_sample)
         if re_groups is not None:
             property_list = re_groups.group().replace('}}', '').split('|')[1:]
